==> jc-1.4.0.tar.gz: jas/LineTableAttr.h <==
// public class jas.LineTableAttr

// class file dependencies
// @dep_class 923a3cf467573ac8 jas_LineTableAttr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_LineTableAttr_H_
#define _JC_jas_LineTableAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_LineTableAttr$sub_refs	_jc_jas_LineTableAttr$sub_refs;
typedef struct _jc_jas_LineTableAttr$sub_nonrefs	_jc_jas_LineTableAttr$sub_nonrefs;
typedef struct _jc_jas_LineTableAttr$refs	_jc_jas_LineTableAttr$refs;
typedef struct _jc_jas_LineTableAttr$nonrefs	_jc_jas_LineTableAttr$nonrefs;
typedef struct _jc_jas_LineTableAttr$object	_jc_jas_LineTableAttr$object;

typedef struct _jc_jas_LineTableAttr$fields_struct	_jc_jas_LineTableAttr$fields_struct;
typedef const struct _jc_jas_LineTableAttr$vmethods	_jc_jas_LineTableAttr$vmethods;
typedef const struct _jc_jas_LineTableAttr$vtable	_jc_jas_LineTableAttr$vtable;
typedef const struct _jc_jas_LineTableAttr$vtype	_jc_jas_LineTableAttr$vtype;

// Class fields structure
struct _jc_jas_LineTableAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_LineTableAttr$fields_struct _jc_jas_LineTableAttr$class_fields;

// Constructors
extern void _jc_jas_LineTableAttr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_LineTableAttr$object *);

// Virtual methods
extern void _jc_jas_LineTableAttr$method$addEntry$45674e3707f73333(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_Label$object *, jint);
extern void _jc_jas_LineTableAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_LineTableAttr$method$size$345df5220fc60ade(_jc_env *, struct _jc_jas_LineTableAttr$object *);
extern void _jc_jas_LineTableAttr$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_LineTableAttr$method_info$addEntry$45674e3707f73333;
extern _jc_method _jc_jas_LineTableAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LineTableAttr$method_info$size$345df5220fc60ade;
extern _jc_method _jc_jas_LineTableAttr$method_info$write$d61e8c36d8c1cacd;

// Static methods
extern void _jc_jas_LineTableAttr$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_jas_LineTableAttr$vmethods {
	void	(*addEntry$45674e3707f73333)(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_Label$object *, jint);
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_jas_LineTableAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_LineTableAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_LineTableAttr$vmethods	jas_LineTableAttr;
};

// Vtype
struct _jc_jas_LineTableAttr$vtype {
	_jc_type			type;
	_jc_jas_LineTableAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LineTableAttr$sub_refs {
	struct _jc_java_util_Vector$object	*line;
	struct _jc_java_util_Vector$object	*pc;
};

// Reference instance fields (object)
struct _jc_jas_LineTableAttr$refs {
    _jc_jas_LineTableAttr$sub_refs	jas_LineTableAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LineTableAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_LineTableAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_LineTableAttr$sub_nonrefs	jas_LineTableAttr;
};

// Object instance structure
struct _jc_jas_LineTableAttr$object {
	_jc_jas_LineTableAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LineTableAttr$vtype	*vtype;
	_jc_jas_LineTableAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LineTableAttr$vtype _jc_jas_LineTableAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LineTableAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LineTableAttr$class_object;

#endif	/* _JC_jas_LineTableAttr_H_ */

==> jc-1.4.6.tar.gz: jas/LineTableAttr.h <==
// public class jas.LineTableAttr

// class file dependencies
// @dep_class 923a3cf467573ac8 jas_LineTableAttr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_LineTableAttr_H_
#define _JC_jas_LineTableAttr_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_Label$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_LineTableAttr$sub_refs	_jc_jas_LineTableAttr$sub_refs;
typedef struct _jc_jas_LineTableAttr$sub_nonrefs	_jc_jas_LineTableAttr$sub_nonrefs;
typedef struct _jc_jas_LineTableAttr$refs	_jc_jas_LineTableAttr$refs;
typedef struct _jc_jas_LineTableAttr$nonrefs	_jc_jas_LineTableAttr$nonrefs;
typedef struct _jc_jas_LineTableAttr$object	_jc_jas_LineTableAttr$object;

typedef struct _jc_jas_LineTableAttr$fields_struct	_jc_jas_LineTableAttr$fields_struct;
typedef const struct _jc_jas_LineTableAttr$vmethods	_jc_jas_LineTableAttr$vmethods;
typedef const struct _jc_jas_LineTableAttr$vtable	_jc_jas_LineTableAttr$vtable;
typedef const struct _jc_jas_LineTableAttr$vtype	_jc_jas_LineTableAttr$vtype;

// Class fields structure
struct _jc_jas_LineTableAttr$fields_struct {
	struct _jc_jas_CP$object	*attr;
};
extern _jc_jas_LineTableAttr$fields_struct _jc_jas_LineTableAttr$class_fields;

// Constructors
extern void _jc_jas_LineTableAttr$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jas_LineTableAttr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_LineTableAttr$method$addEntry$45674e3707f73333(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_Label$object *, jint) _JC_JCNI_ATTR;
extern void _jc_jas_LineTableAttr$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_LineTableAttr$method$size$345df5220fc60ade(_jc_env *, struct _jc_jas_LineTableAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_LineTableAttr$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_LineTableAttr$method_info$addEntry$45674e3707f73333;
extern _jc_method _jc_jas_LineTableAttr$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_LineTableAttr$method_info$size$345df5220fc60ade;
extern _jc_method _jc_jas_LineTableAttr$method_info$write$d61e8c36d8c1cacd;

// Static methods
extern void _jc_jas_LineTableAttr$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jas_LineTableAttr$vmethods {
	void	(*addEntry$45674e3707f73333)(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_Label$object *, jint) _JC_JCNI_ATTR;
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_jas_LineTableAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_LineTableAttr$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_LineTableAttr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_LineTableAttr$vmethods	jas_LineTableAttr;
};

// Vtype
struct _jc_jas_LineTableAttr$vtype {
	_jc_type			type;
	_jc_jas_LineTableAttr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_LineTableAttr$sub_refs {
	struct _jc_java_util_Vector$object	*line;
	struct _jc_java_util_Vector$object	*pc;
};

// Reference instance fields (object)
struct _jc_jas_LineTableAttr$refs {
    _jc_jas_LineTableAttr$sub_refs	jas_LineTableAttr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_LineTableAttr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_LineTableAttr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_LineTableAttr$sub_nonrefs	jas_LineTableAttr;
};

// Object instance structure
struct _jc_jas_LineTableAttr$object {
	_jc_jas_LineTableAttr$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_LineTableAttr$vtype	*vtype;
	_jc_jas_LineTableAttr$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_LineTableAttr$vtype _jc_jas_LineTableAttr$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_LineTableAttr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_LineTableAttr$class_object;

#endif	/* _JC_jas_LineTableAttr_H_ */
